from flask import Blueprint, request
from markupsafe import escape
from web_utils.get_arg import get_arg
from web_utils.run import run
import os

from data.document import Document

bp = Blueprint('api_document', __name__, url_prefix='/api/doc')

@bp.route('/build')
def build():
	doc_name = get_arg('doc')
	branch = get_arg('branch', 'master')
	apikey = get_arg('apikey')
	doc = Document(doc_name, branch)
	
	if doc.get_api_key() != apikey:
		raise Exception("Invalid API key")
	
	output = ""
	output += "\n# Pulling source...\n"
	output += doc.pull()
	
	output += "\n# Compiling...\n"
	output += doc.build()
	
	return output.replace('\n', '<br/>')

@bp.route('/clone')
def clone():
	repo = get_arg('repo')
	doc_name = get_arg('doc', os.path.splitext(os.path.basename(repo))[0])
	branch = get_arg('branch', 'master')
	source_dir = get_arg('source', 'source')
	
	output = Document.clone(repo, branch, doc_name, source_dir)
	
	return output.replace('\n', '<br/>')
